@@ -44,11 +44,10 @@
 #endif
 
 //#define AVI_DEBUG
-
 #ifdef HAVE_ENDIAN_H
 # include <endian.h>
 #endif
-#if BYTE_ORDER == BIG_ENDIAN
+#if defined(BYTE_ORDER) && (BYTE_ORDER == BIG_ENDIAN)
 # define SWAP2(x) (((x>>8) & 0x00ff) |\
                    ((x<<8) & 0xff00))
 
@@ -75,7 +74,7 @@ typedef unsigned char boolean;
 /* Macro to convert expressions of form 'F','O','U','R' to
    numbers of type FOURCC: */
 
-#if BYTE_ORDER == BIG_ENDIAN
+#if defined(BYTE_ORDER) && (BYTE_ORDER == BIG_ENDIAN)
 # define MAKEFOURCC(a,b,c,d) ((((DWORD)a)<<24) | (((DWORD)b)<<16) | \
                               (((DWORD)c)<< 8) | ( (DWORD)d)      )
 #else
@@ -115,7 +114,7 @@ typedef unsigned char boolean;
 
 static void FOURCC2Str(FOURCC fcc, char* s)
 {
-#if BYTE_ORDER == BIG_ENDIAN
+#if defined(BYTE_ORDER) && (BYTE_ORDER == BIG_ENDIAN)
     s[0]=(fcc >> 24) & 0xFF;
     s[1]=(fcc >> 16) & 0xFF;
     s[2]=(fcc >>  8) & 0xFF;
@@ -624,7 +623,7 @@ static boolean ProcessChunk(int fd, off_t filepos, off_t filesize,
 	    duration = SWAP4(duration);
 	    if (size!=0)
 	    printf("\t\t [%6ld] 0x%016llx 0x%08lx %8d\n", u++, offset, size,
-		    duration);
+		    (int)duration);
 	    datapos += 16;
 	}
 	break;
@@ -648,7 +647,7 @@ static boolean ProcessChunk(int fd, off_t filepos, off_t filesize,
 	    key  = key&0x80000000?0:1;
 	    size &= 0x7fffffff;
 	    if (size!=0)
-	    printf("\t\t [%6ld] 0x%08lx 0x%08lx key=%s\n", u++, offset, size,
+	    printf("\t\t [%6ld] 0x%08x 0x%08x key=%s\n", u++, offset, size,
 		    key?"yes":"no");
 	    datapos += 8;
 	}
