@@ -880,7 +880,7 @@ int main(int argc, char *argv[]) {
   off_t  file_size;
   double manual_sync;
 
-  fprintf(stdout, "This program is not finished. Iy will probably not "
+  fprintf(stdout, "This program is not finished. It will probably not "
           "work for your files. It might work for files created with "
           "ogmsplit. It might not. Please do not ask me when it will "
           "be ready - I simply don't know. If you want to experiment "
